@@ -5,7 +5,7 @@
  * notice and this notice are preserved.
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
