@@ -129,7 +129,7 @@ gnutls_psk_set_client_credentials (gnutls_psk_client_credentials_t res,
 	}
 
       ret = gnutls_hex_decode (key, (char *) res->key.data, &size);
-      res->key.size = (unsigned int)size;
+      res->key.size = (unsigned int) size;
       if (ret < 0)
 	{
 	  gnutls_assert ();
@@ -407,14 +407,17 @@ int
 gnutls_hex_encode (const gnutls_datum_t * data, char *result,
 		   size_t * result_size)
 {
-  if (*result_size < data->size + data->size + 1)
+size_t res = data->size + data->size + 1;
+
+  if (*result_size < res)
     {
       gnutls_assert ();
       return GNUTLS_E_SHORT_MEMORY_BUFFER;
     }
 
   _gnutls_bin2hex (data->data, data->size, result, *result_size);
-
+  *result_size = res;
+  
   return 0;
 }
 
